@@ -1,5 +1,7 @@
 # -*- coding: UTF-8 -*-
-"""This module contains all Exception classes to manage errors.
+"""This module contains all exceptions raised by `OERPLib` when an error
+occurred.
+
 """
 #import traceback, sys
 
@@ -15,37 +17,13 @@ class Error(Exception):
         return u"{message}".format(message=self.message)
 
 
-class DMSConnectionError(Error):
-    pass
-
-
-class LoginError(Error):
-    pass
-
-
-class ExecuteQueryError(Error):
-    pass
-
-
-class WorkflowQueryError(Error):
-    pass
-
-
-class ReportError(Error):
+class RPCError(Error):
+    """Exception raised when an error related to a RPC query occurs."""
     pass
 
 
 class InternalError(Error):
+    """Exception raised when an error occurred during an internal operation."""
     pass
 
-
-class NotAllowedError(Error):
-    def __init__(self, message):
-        super(NotAllowedError, self).__init__(message)
-
-
-class UnknownError(Error):
-    def __init__(self, message):
-        super(UnknownError, self).__init__(message)
-
 # vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
