@@ -247,7 +247,7 @@ class OERP(object):
     # ------------------------- #
 
     def browse(self, osv_name, ids, context=None):
-        """Return a browsable record (or a list of records if ``ids`` is a list)
+        """Browse one record or several records (if ``ids`` is a list of IDs)
         according to the model ``osv_name``.
 
         >>> oerp.browse('res.partner', 1)
@@ -257,14 +257,11 @@ class OERP(object):
         [u'Your Company', u'ASUStek']
 
         :return: a BrowseRecord instance
+        :return: a generator to iterate on BrowseRecord instances
         :raise: :class:`oerplib.error.RPCError`
 
         """
-        if isinstance(ids, list):
-            return [self.browse(osv_name, o_id)
-                    for o_id in ids]
-        else:
-            return self._pool.get(osv_name).browse(ids)
+        return self.get(osv_name).browse(ids, context)
 
     def search(self, osv_name, args=None, offset=0, limit=None, order=None,
                context=None, count=False):
@@ -364,7 +361,7 @@ class OERP(object):
         """
         if not isinstance(browse_record, osv.BrowseRecord):
             raise ValueError(u"An instance of BrowseRecord is required")
-        return self._pool.get_by_class(browse_record.__class__).write(
+        return self._pool.get_by_class(browse_record.__class__)._write_record(
                 browse_record, context)
 
     def unlink_record(self, browse_record, context=None):
@@ -375,10 +372,10 @@ class OERP(object):
         """
         if not isinstance(browse_record, osv.BrowseRecord):
             raise ValueError(u"An instance of BrowseRecord is required")
-        return self._pool.get_by_class(browse_record.__class__).unlink(
+        return self._pool.get_by_class(browse_record.__class__)._unlink_record(
                 browse_record, context)
 
-    def refresh(self, browse_record):
+    def refresh(self, browse_record, context=None):
         """Restore original values of the ``browse_record`` from data
         retrieved on the OpenERP server.
         Thus, all changes made locally on the record are canceled.
@@ -386,8 +383,8 @@ class OERP(object):
         :raise: :class:`oerplib.error.RPCError`
 
         """
-        return self._pool.get_by_class(browse_record.__class__).refresh(
-                browse_record)
+        return self._pool.get_by_class(browse_record.__class__)._refresh(
+                browse_record, context)
 
     def reset(self, browse_record):
         """Cancel all changes made locally on the ``browse_record``.
@@ -395,7 +392,7 @@ class OERP(object):
         Therefore, values restored may be outdated.
 
         """
-        return self._pool.get_by_class(browse_record.__class__).reset(
+        return self._pool.get_by_class(browse_record.__class__)._reset(
                 browse_record)
 
     def get_osv_name(self, browse_record):
@@ -412,4 +409,13 @@ class OERP(object):
             raise ValueError(u"Value is not a browse_record.")
         return browse_record.__osv__['name']
 
+    def get(self, osv_name):
+        """.. versionadded:: 0.5.0
+
+        Return a proxy of the OSV class `osv_name` built from the `OpenERP`
+        server. See <TODO>.
+
+        """
+        return self._pool.get(osv_name)
+
 # vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
